<?php

/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Stencil Pro
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function stencil_body_classes($classes) {
	// Adds a class of hfeed to non-singular pages.
	if (!is_singular()) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if (!is_active_sidebar('sidebar-1')) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter('body_class', 'stencil_body_classes');

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function stencil_pingback_header() {
	if (is_singular() && pings_open()) {
		printf('<link rel="pingback" href="%s">', esc_url(get_bloginfo('pingback_url')));
	}
}
add_action('wp_head', 'stencil_pingback_header');

/**
 * Adds custom class to the array of posts classes.
 */
function stencil_post_classes($classes, $class, $post_id) {
	$classes[] = 'entry';

	return $classes;
}
add_filter('post_class', 'stencil_post_classes', 10, 3);

/**
 * Customize tag cloud widget
 */
function stencil_customize_tag_cloud($args) {
	$args['largest']  = 13;
	$args['smallest'] = 13;
	$args['unit']     = 'px';
	$args['number']   = 20;
	return $args;
}
add_filter('widget_tag_cloud_args', 'stencil_customize_tag_cloud');

/**
 * Change the excerpt more string.
 */
function stencil_excerpt_more($more) {
	return '&hellip;';
}
add_filter('excerpt_more', 'stencil_excerpt_more');

/**
 * Limit excerpt length
 */
function stencil_excerpt_length($length) {
	return 25;
}
add_filter('excerpt_length', 'stencil_excerpt_length', 999);

/**
 * Returns true if comment is by author of the post.
 *
 * @see get_comment_class()
 */
function stencil_is_comment_by_post_author($comment = null) {
	if (is_object($comment) && $comment->user_id > 0) {
		$user = get_userdata($comment->user_id);
		$post = get_post($comment->comment_post_ID);
		if (!empty($user) && !empty($post)) {
			return $comment->user_id === $post->post_author;
		}
	}
	return false;
}

/**
 * Add extra user fields
 */
function stencil_user_fields($contactmethods) {

	$contactmethods['twitter']     = esc_html__('Twitter URL', 'stencil-pro');
	$contactmethods['facebook']    = esc_html__('Facebook URL', 'stencil-pro');
	$contactmethods['instagram']   = esc_html__('Instagram URL', 'stencil-pro');
	$contactmethods['pinterest']   = esc_html__('Pinterest URL', 'stencil-pro');
	$contactmethods['linkedin']    = esc_html__('Linkedin URL', 'stencil-pro');
	$contactmethods['dribbble']    = esc_html__('Dribbble URL', 'stencil-pro');

	return $contactmethods;
}
add_filter('user_contactmethods', 'stencil_user_fields');

/**
 * Modifies the theme layout.
 */
function stencil_mod_theme_layout($layout) {

	// Change the layout to Full Width on Attachment page.
	if (is_attachment() && wp_attachment_is_image()) {
		$post_layout = get_post_layout(get_queried_object_id());
		if ('default' === $post_layout) {
			$layout = 'full-width';
		}
	}

	// Layout on Archive & Search page.
	if (is_archive() || is_search() || is_404()) {
		$layout = 'full-width';
	}

	return $layout;
}
add_filter('theme_mod_theme_layout', 'stencil_mod_theme_layout', 15);
